import{c as m,d as p,W as B,g as b,D as c,A as $,O as u,u as d,aq as h,M as w,E as f,h as v,I,b1 as g,e as y}from"./lucide-F1B1VpI-.js";import{m as k,M}from"./Button-9Ou4QCZy.js";import{M as C}from"./index-kQIztB-E.js";import{c as L}from"./vuetify-BRgYuWPG.js";import{_ as P}from"./index-ByIRZxAe.js";const S=t=>{const o=m(()=>{const{variant:n,showMenuBtn:e,...s}=t,i={...s,"aria-label":t["aria-label"]};return C(n).with("compact",()=>({...i,density:t.density||"compact",class:t.class?`list-item-compact ${t.class}`:"list-item-compact"})).with("comfortable",()=>({...i,density:t.density||"comfortable",class:t.class?`list-item-comfortable ${t.class}`:"list-item-comfortable"})).with("default",()=>({...i,class:t.class?`list-item-default ${t.class}`:"list-item-default"})).otherwise(()=>({...i,class:t.class?`list-item-default ${t.class}`:"list-item-default"}))}),l=m(()=>k("list-item-main",t.variant&&`list-item--${t.variant}`));return{listItemProps:o,listItemClasses:l}},D={variant:"default",showMenuBtn:!1,link:!1},N=p({__name:"ListItem",props:B({showMenuBtn:{type:Boolean},variant:{},active:{type:Boolean},disabled:{type:Boolean},link:{type:Boolean},nav:{type:Boolean},density:{},height:{},lines:{type:[String,Boolean]},subtitle:{},title:{},value:{type:[String,Number,Boolean,Object]},color:{},rounded:{type:[Boolean,String,Number]},tag:{},to:{},href:{},replace:{type:Boolean},exact:{type:Boolean},class:{},style:{},"aria-label":{},role:{}},D),emits:["click","menu","input"],setup(t){const o=t,{listItemProps:l,listItemClasses:n}=S(o);return(e,s)=>{const i=g("hold");return b((y(),c(L,$(d(l),{class:d(n),onClick:s[1]||(s[1]=a=>e.$emit("click",a)),onContextmenu:s[2]||(s[2]=u(a=>e.$emit("menu",a),["right","prevent"])),onInput:s[3]||(s[3]=a=>e.$emit("input",a))}),h({_:2},[w(e.$slots,(a,r)=>({name:r,fn:f(()=>[v(e.$slots,r,{},void 0,!0)])})),e.$slots.append||t.showMenuBtn?{name:"append",fn:f(()=>[v(e.$slots,"append",{},void 0,!0),t.showMenuBtn?(y(),c(M,{key:0,variant:"icon",icon:"mdi-dots-vertical","aria-label":"Show context menu",onClick:s[0]||(s[0]=u(a=>e.$emit("menu",a),["stop"]))})):I("",!0)]),key:"0"}:void 0]),1040,["class"])),[[i,a=>e.$emit("menu",a)]])}}}),E=P(N,[["__scopeId","data-v-46e3c802"]]);export{E as L};
