import{C as S}from"./Container-DnmqEBzf.js";import{_ as w}from"./ProviderIcon.vue_vue_type_style_index_0_lang-B65iU32Z.js";import{a,_ as z}from"./index-ByIRZxAe.js";import{u as L}from"./vue-router-BpTQq1WE.js";import{b as T,a as B,c as _,S as f,T as C,d as l,z as v}from"./vuetify-BRgYuWPG.js";import{d as D,o as E,r as N,D as m,E as t,H as n,b as h,M as k,c as F,F as x,e as r,$ as c,a1 as d,I as A,u as y}from"./lucide-F1B1VpI-.js";import{u as H}from"./vue-i18n-fACdQrNQ.js";import"./index-kQIztB-E.js";import"./color-CcshWhNz.js";import"./qrcode-0NlyE7mq.js";import"./marked-i_gIkIP3.js";import"./vueuse-D-YfxAQp.js";/* empty css            */import"./swiper-Bthg8aDK.js";const R=D({__name:"SystemConfig",setup(j){const u=L(),{t:i}=H(),p=N([]),I=[{domain:"logging",name:"settings.system_logging",description:"settings.system_logging_description",icon:"mdi-text-box-search",route:"/settings/serverlogs"},{domain:"genre_management",name:"settings.genre_management",description:"settings.genre_management_description",icon:"mdi-compass-outline",route:"/settings/genremanagement"}],V=F(()=>[...p.value].sort((e,o)=>a.providerManifests[e.domain].name.localeCompare(a.providerManifests[o.domain].name))),$=e=>{const o=i(`settings.core_module.${e.domain}.name`);return o!==`settings.core_module.${e.domain}.name`?o:a.providerManifests[e.domain].name},b=e=>{const o=i(`settings.core_module.${e.domain}.description`);return o!==`settings.core_module.${e.domain}.description`?o:a.providerManifests[e.domain].description},g=function(e){"route"in e&&e.route?u.push(e.route):u.push(`/settings/editcore/${e.domain}`)};return E(async()=>{p.value=await a.getCoreConfigs()}),(e,o)=>(r(),m(S,{variant:"comfortable",class:"settings-overview"},{default:t(()=>[n(B,{class:"settings-main-card"},{default:t(()=>[n(T,{class:"settings-list"},{default:t(()=>[(r(!0),h(x,null,k(V.value,s=>(r(),m(_,{key:s.domain,ripple:!0,class:"settings-list-item",onClick:M=>g(s)},{prepend:t(()=>[n(v,{color:"blue",size:"48"},{default:t(()=>[n(w,{domain:s.domain,size:24,color:"white"},null,8,["domain"])]),_:2},1024)]),append:t(()=>[s.last_error?(r(),m(l,{key:0,color:"red",icon:"mdi-alert-circle",class:"mr-2",title:s.last_error},null,8,["title"])):A("",!0),n(l,{icon:"mdi-chevron-right"})]),default:t(()=>[n(f,{class:"text-h6"},{default:t(()=>[c(d($(s)),1)]),_:2},1024),n(C,null,{default:t(()=>[c(d(b(s)),1)]),_:2},1024)]),_:2},1032,["onClick"]))),128)),(r(),h(x,null,k(I,s=>n(_,{key:s.domain,ripple:!0,class:"settings-list-item",onClick:M=>g(s)},{prepend:t(()=>[n(v,{color:"purple",size:"48"},{default:t(()=>[n(l,{icon:s.icon,size:"24",color:"white"},null,8,["icon"])]),_:2},1024)]),append:t(()=>[n(l,{icon:"mdi-chevron-right"})]),default:t(()=>[n(f,{class:"text-h6"},{default:t(()=>[c(d(y(i)(s.name)),1)]),_:2},1024),n(C,null,{default:t(()=>[c(d(y(i)(s.description)),1)]),_:2},1024)]),_:2},1032,["onClick"])),64))]),_:1})]),_:1})]),_:1}))}}),se=z(R,[["__scopeId","data-v-78d3be9e"]]);export{se as default};
