.listview-item-skeleton[data-v-b8be0a9f]{display:flex;align-items:center;height:70px;padding:8px 16px;gap:16px}.skeleton-thumbnail[data-v-b8be0a9f]{width:50px;height:50px;border-radius:4px;flex-shrink:0}.skeleton-content[data-v-b8be0a9f]{flex:1;display:flex;flex-direction:column;gap:8px;min-width:0}.skeleton-title[data-v-b8be0a9f]{height:16px;width:60%;max-width:300px}.skeleton-subtitle[data-v-b8be0a9f]{height:14px;width:40%;max-width:200px}.skeleton-duration[data-v-b8be0a9f]{width:45px;height:14px;flex-shrink:0}.panelview-item-skeleton[data-v-fbebf64d]{display:flex;flex-direction:column;gap:8px;padding:8px}.skeleton-image[data-v-fbebf64d]{aspect-ratio:1;width:100%;border-radius:8px}.skeleton-info[data-v-fbebf64d]{display:flex;flex-direction:column;gap:6px;padding:0 4px}.skeleton-title[data-v-fbebf64d]{height:16px;width:85%}.skeleton-artist[data-v-fbebf64d]{height:14px;width:60%}.skeleton-actions[data-v-fbebf64d]{display:flex;gap:8px;padding:0 4px}.skeleton-icon[data-v-fbebf64d]{width:24px;height:24px;border-radius:50%}.unavailable[data-v-b2115336],.dimmed[data-v-b2115336]{opacity:.3}.hidden[data-v-b2115336]{opacity:0}.hiresicon[data-v-b2115336]{margin-top:5px;margin-right:15px;margin-left:15px;filter:invert(100%)}.hiresicondark[data-v-b2115336]{margin-top:5px;margin-right:15px;margin-left:15px}.v-card.unavailable[data-v-408ff1cd]{opacity:.3}.panel-item[data-v-408ff1cd]{height:100%;padding:10px;border:none;border-style:none!important}.panel-item-checkbox[data-v-408ff1cd]{position:absolute;width:100%;height:auto;left:0;right:0}.panel-item-details[data-v-408ff1cd]{margin-top:10px;padding-left:0!important;padding-right:0!important;height:40px}.panel-item-actions[data-v-408ff1cd]{gap:0;padding:0;margin:10px 0 0;height:40px;min-height:unset!important}panel-item-details[data-v-408ff1cd] .v-list-item__content{height:30px}.v-card--active[data-v-408ff1cd]{background-color:red}.hiresicon[data-v-408ff1cd]{margin-right:10px}.hiresiconinverted[data-v-408ff1cd]{margin-right:10px;filter:invert(100%)}.thumb-container[data-v-408ff1cd]{position:relative;display:flex;align-items:center;justify-content:center}.provider-icon-overlay[data-v-408ff1cd]{position:absolute;left:-10px;top:0;z-index:2}.col-2[data-v-22149e60]{width:50%;max-width:50%;flex-basis:50%;padding:8px}.col-3[data-v-22149e60]{width:33.3%;max-width:33.3%;flex-basis:33.3%;padding:8px}.col-4[data-v-22149e60]{width:25%;max-width:25%;flex-basis:25%;padding:8px}.col-5[data-v-22149e60]{width:20%;max-width:20%;flex-basis:20%;padding:8px}.col-6[data-v-22149e60]{width:16.6%;max-width:16.6%;flex-basis:16.6%;padding:8px}.col-7[data-v-22149e60]{width:14.2%;max-width:14.2%;flex-basis:14.2%;padding:8px}.col-8[data-v-22149e60]{width:12.5%;max-width:12.5%;flex-basis:12.5%;padding:8px}.col-9[data-v-22149e60]{width:11.1%;max-width:11.1%;flex-basis:11.1%;padding:8px}.col-10[data-v-22149e60]{width:10%;max-width:10%;flex-basis:10%;padding:8px}
