import{c as t}from"./index-ByIRZxAe.js";import{d as n,b as o,ad as r,u as c,h as l,e as p}from"./lucide-F1B1VpI-.js";const u=n({__name:"CardContent",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(a){const e=a;return(s,d)=>(p(),o("div",{"data-slot":"card-content",class:r(c(t)("px-6",e.class))},[l(s.$slots,"default")],2))}});export{u as _};
