import{d as o,b as t,H as n,av as r,e as a}from"./lucide-F1B1VpI-.js";const u=o({__name:"PartyModeGuestLayout",setup(s){return(c,_)=>{const e=r("router-view");return a(),t("div",null,[n(e)])}}});export{u as default};
