import{c as a}from"./index-ByIRZxAe.js";import{d as r,b as t,ad as l,u as n,h as c,e as p}from"./lucide-F1B1VpI-.js";const d=r({__name:"DialogFooter",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(e){const s=e;return(o,f)=>(p(),t("div",{"data-slot":"dialog-footer",class:l(n(a)("flex flex-col-reverse gap-2 sm:flex-row sm:justify-end",s.class))},[c(o.$slots,"default")],2))}});export{d as _};
