.faceted-filter-content[data-v-4ebcab1d]{padding:8px 10px 10px;display:flex;flex-direction:column;gap:8px}.faceted-filter-list[data-v-4ebcab1d]{max-height:260px;overflow-y:auto;display:flex;flex-direction:column;gap:4px}.faceted-filter-item[data-v-4ebcab1d]{display:flex;align-items:center;gap:8px;width:100%;padding:4px 6px;border-radius:4px;background:transparent;border:none;cursor:pointer;text-align:left}.faceted-filter-item[data-v-4ebcab1d]:hover{background-color:rgba(var(--v-theme-on-surface),.04)}.faceted-filter-clear[data-v-4ebcab1d]{margin-top:4px;width:100%;padding:4px 6px;font-size:.8rem;border-radius:4px;border:none;background:transparent;color:rgba(var(--v-theme-on-surface),.7);cursor:pointer}.faceted-filter-clear[data-v-4ebcab1d]:hover{background-color:rgba(var(--v-theme-on-surface),.04)}
